@@ -38,9 +38,8 @@
  ***********************************************************************/
 
 #if 0
-/* These are not ready for prime-time. */
+/* This is not ready for prime-time. */
 #define QUARTER_PERCENT 1
-#define VERTICAL 1
 #endif
 
 #ifndef WINVER
@@ -90,6 +89,7 @@
 #define XtNdiamond ((char *) "diamond")
 #define XtNaux ((char *) "aux")
 #define XtNmathBuffer ((char *) "mathBuffer")
+#define XtNversionOnly ((char *) "versionOnly")
 #define XtCRails ((char *) "Rails")
 #define XtCSpaces ((char *) "Spaces")
 #define XtCBase ((char *) "Base")
@@ -172,23 +172,6 @@ typedef struct {
 #define ABACUS_QUARTERPERCENT 7
 #define ABACUS_FORMAT 8
 
-#ifdef WINVER
-#ifdef UNIXDELIM
-#define CURRENTDELIM "./"
-#define FINALDELIM "/"
-#else
-#define CURRENTDELIM ".\\"
-#define FINALDELIM "\\"
-#endif
-#else
-#ifdef VMS
-#define CURRENTDELIM "[]"
-#define FINALDELIM ""
-#else
-#define CURRENTDELIM "./"
-#define FINALDELIM "/"
-#endif
-#endif
 #define PRIMARY 0
 #define LEFTAUX 1
 #define RIGHTAUX 2
@@ -229,10 +212,5 @@ typedef struct {
 typedef struct _AbacusRec *AbacusWidget;
 typedef struct _AbacusRec *AbacusDemoWidget;
 
-extern void intCat(char ** string, const char * var1, const int var2);
-#if 0
-extern void stringCat(char ** string, const char * var1, const char * var2);
-#endif
-
 #endif /* _XtAbacus_h */
 /* DON'T ADD STUFF AFTER THIS #endif */
