@@ -28,6 +28,7 @@
 
 /* Methods demo file for Abacus */
 
+#include "file.h"
 #include "AbacusP.h"
 
 #ifndef WINVER
@@ -242,13 +243,13 @@ loadFont(AbacusWidget w)
 	if ((w->abacusDemo.fontInfo = XLoadQueryFont(XtDisplay(w),
 					      w->abacusDemo.font)) == NULL) {
 		(void) sprintf(buf,
-			"Cannot open %s font.\nAttempting %s font as alternate\n",
+			"Can not open %s font.\nAttempting %s font as alternate\n",
 			w->abacusDemo.font, altfontname);
 		DISPLAY_WARNING(buf);
 		if ((w->abacusDemo.fontInfo = XLoadQueryFont(XtDisplay(w),
 						     altfontname)) == NULL) {
 			(void) sprintf(buf,
-				"Cannot open %s alternate font.\nUse the -demofont option to specify a font to use.\n",
+				"Can not open %s alternate font.\nUse the -demofont option to specify a font to use.\n",
 				altfontname);
 			DISPLAY_ERROR(buf);
 		}
@@ -373,7 +374,7 @@ drawText(AbacusWidget w, TextType textType)
 			1, w->abacusDemo.fontHeight +
 			(w->abacusDemo.fontHeight * line),
 			temp, strlen(temp));
-		XFlush(XtDisplay(w));
+		FLUSH(w);
 #endif
 	}
 }
