@@ -35,9 +35,9 @@
   Version 1: 91/02/14 SunView
 */
 
-#ifdef HAVE_MOTIF
+#ifndef WINVER
 static const char aboutHelp[] = {
-	"Version 7.1.3\n"
+	"Abacus Version 7.1.6\n"
 	"Send bugs (reports or fixes) to the author: "
 	"David Bagley <bagleyd@tux.org>\n"
 	"The latest version is at: "
@@ -45,24 +45,29 @@ static const char aboutHelp[] = {
 	"Some coding was also done by Luis Fernandes <elf@ee.ryerson.ca>\n"
 	"and Sarat Chandran <saratcmahadevan@yahoo.com>\n"
 };
+
+static const char optionsHelp[] = {
+	"\t[-geometry [{width}][x{height}] [{+-}{xoff}[{+-}{yoff}]]]\n"
+	"\t[-display [{host}]:[{vs}]] [-[no]mono] [-[no]{reverse|rv}]\n"
+	"\t[-{foreground|fg} {color}] [-{background|bg} {color}]\n"
+	"\t[-{border|bd} {color}] [-frame {color}] [-rail {color}]\n"
+	"\t[-bead {color}] [-rails {int}] [-[no]slot] [-[no]diamond]\n"
+	"\t[-{chinese|japanese|korean|roman|russian|other}]\n"
+	"\t[-base {int}] [-displayBase {int}]\n"
+	"\t[-no]romanNumerals] [-[no]sign] [-[no]quarter]\n"
+	"\t[-tnumber {int}] [-bnumber {int}] [-tfactor {int}]\n"
+	"\t[-bfactor {int}] [-tspaces {int}] [-bspaces {int}]\n"
+	"\t[-[no]torient] [-[no]borient] [-delay msecs]\n"
+	"\t[-[no]sound] [-bumpSound {filename}] [-moveSound {filename}]\n"
+	"\t[-[no]demo] [-[no]script] [-demopath {path}]\n"
+	"\t[-{demofont|demofn} {fontname}]\n"
+	"\t[-{demoforeground|demofg} {color}]\n"
+	"\t[-{demobackground|demobg} {color}] [-version]\n"
+};
+#endif
+
+#ifdef HAVE_MOTIF
 static const char options1Help[] = {
-	"[-geometry [{width}][x{height}] [{+-}{xoff}[{+-}{yoff}]]] "
-	"[-display [{host}]:[{vs}]] [-[no]mono] [-[no]{reverse|rv}]\n"
-	"[-{foreground|fg} {color}] [-{background|bg} {color}] "
-	"[-{border|bd} {color}] [-frame {color}] [-rail {color}]\n"
-	"[-bead {color}] [-rails {int}] [-[no]slot] [-[no]diamond] "
-	"[-{chinese|japanese|korean|roman|russian|other}]\n"
-	"[-base {int}] [-displayBase {int}] "
-	"[-no]romanNumerals] [-[no]sign] [-[no]quarter]\n"
-	"[-tnumber {int}] [-bnumber {int}] [-tfactor {int}] "
-	"[-bfactor {int}] [-tspaces {int}] [-bspaces {int}]\n"
-	"[-[no]torient] [-[no]borient] [-delay msecs] "
-	"[-[no]sound] [-bumpsound {filename}] [-movesound {filename}]\n"
-	"[-[no]demo] [-[no]script] [-demopath {path}] "
-	"[-{demofont|demofn} {fontname}]\n"
-	"[-{demoforeground|demofg} {color}] "
-	"[-{demobackground|demobg} {color}]\n"
-	"\n"
 	"-geometry {+|-}X{+|-}Y    "
 	"This option sets the initial position of the abacus "
 	"window (resource name \"geometry\").\n"
@@ -145,10 +150,14 @@ static const char options1Help[] = {
 	"        \"displayBase\" is greater than the \"base\" it "
 	"looses some precision.  Also no rounding is done.\n"
 };
+
 static const char options2Help[] = {
+	"-[no]vertical    "
+	"This option allows you to set the abacus to allow "
+	"a Russian orientation (resource name \"vertical\").\n"
 	"-[no]romanNumerals    "
-	"This option allows you to set the the abacus to "
-	"allow Roman Numerals (resource name\n"
+	"This option allows you to set the abacus to allow "
+	"Roman Numerals (resource name\n"
 	"        \"romanNumerals\").  Roman Numerals above 3999 "
 	"are normally represented with bars on top, due to ASCII\n"
 	"        constraints this is represented instead in lower "
@@ -156,11 +165,11 @@ static const char options2Help[] = {
 	"        above 3,999,999 were not represented historically.  "
 	"Roman numerals change with displayBase in an \"experimental\" way.\n"
 	"-[no]sign    "
-	"This option allows you to set the the abacus to "
-	"allow negatives (resource name \"sign\").\n"
+	"This option allows you to set the abacus to allow "
+	"negatives (resource name \"sign\").\n"
 	"-[no]quarter    "
-	"This option allows you to set the the abacus to "
-	"allow quarters (resource name \"quarter\").\n"
+	"This option allows you to set the abacus to allow "
+	"quarters (resource name \"quarter\").\n"
 	"-tnumber int    "
 	"This option specifies the number  of  beads on top "
 	"(resource name \"topNumber\").\n"
@@ -192,9 +201,9 @@ static const char options2Help[] = {
 	"-[no]sound    "
 	"This option specifies if a sliding bead should "
 	"make a sound or not (resource name \"sound\").\n"
-	"-bumpsound filename    "
+	"-bumpSound filename    "
 	"This option specifies the file for the bump sound."
-	"-movesound filename    "
+	"-moveSound filename    "
 	"This option specifies the file for the move sound."
 	"-[no]demo    "
 	"This option specifies to run in demo mode.  In  this "
@@ -235,8 +244,11 @@ static const char options2Help[] = {
 	"This option specifies the background of  the  abacus "
 	"demo window (resource name\n"
 	"        \"demoBackground\").\n"
+	"-version    "
+	"This option tells you what version of xcubes you have.\n"
 };
 #endif
+
 #if defined(HAVE_MOTIF) || defined(WINVER)
 static const char descriptionHelp[] = {
 	"This is an implementation of the classic Chinese abacus "
@@ -301,6 +313,7 @@ static const char descriptionHelp[] = {
 	"cube-root computations to be performed with equal ease as addition\n"
 	"and subtraction."
 };
+
 static const char featuresHelp[] = {
 	"Click \"mouse-left\" button on a bead you want to  move.   The "
 	"beads  will  shift  themselves  to vacate the row and column\n"
@@ -318,7 +331,9 @@ static const char featuresHelp[] = {
 	"Press \"F\" or \"f\" keys to switch between Chinese, Japanese, "
 	"Korean, Roman, and Russian formats.\n"
 	"\n"
-	"Press \"R\" or \"r\" keys to toggle the availability of Roman "
+	"Press \"V\" or \"v\" keys to toggle vertical Russian orientation.\n"
+	"\n"
+	"Press \"M\" or \"m\" keys to toggle the availability of Roman "
 	"Numerals.\n"
 	"\n"
 	"Press \"S\" or \"s\" keys to toggle the availability of sign "
@@ -347,6 +362,7 @@ static const char featuresHelp[] = {
 	"the  pointer  in the window will restart the demo (beginning\n"
 	"of current lesson)."
 };
+
 static const char referencesHelp[] = {
 	"Luis Fernandes  http://www.ee.ryerson.ca/~elf/abacus/\n"
 	"Lee Kai-chen, How to Learn Lee's Abacus, 1958, 58 pages.\n"
@@ -358,6 +374,7 @@ static const char referencesHelp[] = {
 	"Dover Publications, Inc 1958, pp 156-195.\n"
 };
 #endif
+
 static const char *formatString[] =
 {
 	"Chinese", "Japanese", "Korean", "Roman", "Russian", "Other"
@@ -451,11 +468,11 @@ SetAbacus(AbacusWidget w, int reason)
 		case ABACUS_INC:
 		case ABACUS_DEC:
 		case ABACUS_FORMAT:
+		case ABACUS_VERTICAL:
 		case ABACUS_ROMANNUMERAL:
 		case ABACUS_SIGN:
 		case ABACUS_QUARTER:
 		case ABACUS_QUARTERPERCENT:
-		case ABACUS_VERTICAL:
 			break;
 	}
 }
@@ -621,6 +638,14 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 						ClearAbacus(&widget);
 					}
 					break;
+				case IDM_VERTICAL:
+					widget.core.hDC = GetDC(hWnd);
+					(void) SelectObject(widget.core.hDC,
+						GetStockObject(NULL_PEN));
+					VerticalAbacus(&widget);
+					(void) ReleaseDC(hWnd,
+						widget.core.hDC);
+					break;
 				case IDM_ROMANNUMERAL:
 					widget.core.hDC = GetDC(hWnd);
 					(void) SelectObject(widget.core.hDC,
@@ -653,14 +678,6 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 					(void) ReleaseDC(hWnd,
 						widget.core.hDC);
 					break;
-				case IDM_VERTICAL:
-					widget.core.hDC = GetDC(hWnd);
-					(void) SelectObject(widget.core.hDC,
-						GetStockObject(NULL_PEN));
-					VerticalAbacus(&widget);
-					(void) ReleaseDC(hWnd,
-						widget.core.hDC);
-					break;
 				case IDM_DEMO:
 					DemoAbacusDemo(&widget);
 					ResizeAbacus(&widget);
@@ -725,7 +742,7 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 
 int WINAPI
 WinMain(HINSTANCE hInstance, HINSTANCE hPrevInstance, LPSTR lpCmdLine,
-	int numCmdShow)
+		int numCmdShow)
 {
 	HWND hWnd;
 	MSG msg;
@@ -773,10 +790,7 @@ WinMain(HINSTANCE hInstance, HINSTANCE hPrevInstance, LPSTR lpCmdLine,
 }
 
 #else
-#include <stdlib.h>
-#include <stdio.h>
-#include <X11/Intrinsic.h>
-#include <X11/StringDefs.h>
+#include "xwin.h"
 #include <X11/Shell.h>
 #include <X11/cursorfont.h>
 #ifdef HAVE_MOTIF
@@ -836,7 +850,8 @@ static Widget signSwitch, quarterSwitch, quarterPercentSwitch;
 #endif
 static Widget tracker;
 static Widget descriptionDialog, featuresDialog;
-static Widget options1Dialog, options2Dialog, referencesDialog, aboutDialog;
+static Widget optionsDialog, options1Dialog, options2Dialog;
+static Widget referencesDialog, aboutDialog;
 static Widget clearDialog;
 static const char *complexityString[] =
 {
@@ -844,6 +859,7 @@ static const char *complexityString[] =
 };
 static char *mathBuffer = NULL;
 static Boolean baseSet = False;
+static Arg arg[4];
 #else
 static Widget shell = NULL;
 static char titleDsp[TITLELEN];
@@ -852,56 +868,12 @@ static Pixmap abacusIcon = None;
 static char titleDspDemo[FILENAMELEN + 6];
 static Widget topLevel, abacus, abacusDemo = NULL;
 static char *progDsp;
-static Arg arg[4];
 
 static void
 Usage(char * programName)
 {
 	(void) fprintf(stderr, "usage: %s\n", programName);
-	(void) fprintf(stderr,
-		"\t[-geometry [{width}][x{height}][{+-}{xoff}[{+-}{yoff}]]]\n");
-	(void) fprintf(stderr,
-		"\t[-display [{host}]:[{vs}]] [-[no]mono] [-[no]{reverse|rv}]\n");
-	(void) fprintf(stderr,
-		"\t[-{foreground|fg} {color}] [-{background|bg} {color}]\n");
-	(void) fprintf(stderr,
-		"\t[-{border|bd} {color}] [-frame {color}] [-rail {color}]\n");
-	(void) fprintf(stderr,
-		"\t[-bead {color}] [-rails {int}] [-[no]slot] [-[no]diamond]\n");
-	(void) fprintf(stderr,
-		"\t[-{chinese|japanese|korean|roman|russian|other}]\n");
-	(void) fprintf(stderr,
-		"\t[-base {int}] [-displayBase {int}] [-[no]romanNumerals]\n");
-#ifdef QUARTER_PERCENT
-	(void) fprintf(stderr,
-		"\t[-[no]sign] [-[no]quarter] [-[no]quarterpercent]\n");
-#else
-	(void) fprintf(stderr,
-		"\t[-[no]sign] [-[no]quarter]\n");
-#endif
-	(void) fprintf(stderr,
-		"\t[-tnumber {int}] [-bnumber {int}] [-tfactor {int}]\n");
-	(void) fprintf(stderr,
-		"\t[-bfactor {int}] [-tspaces {int}] [-bspaces {int}]\n");
-#ifdef VERTICAL
-	(void) fprintf(stderr,
-		"\t[-[no]torient] [-[no]borient] [-[no]vertical]\n");
-#else
-	(void) fprintf(stderr,
-		"\t[-[no]torient] [-[no]borient]\n");
-#endif
-	(void) fprintf(stderr,
-		"\t[-delay msecs] [-[no]sound]\n");
-	(void) fprintf(stderr,
-		"\t[-bumpsound {filename}] [-movesound {filename}]\n");
-	(void) fprintf(stderr,
-		"\t[-[no]demo] [-[no]script]\n");
-	(void) fprintf(stderr,
-		"\t[-demopath {path}] [-{demofont|demofn} {fontname}]\n");
-	(void) fprintf(stderr,
-		"\t[-{demoforeground|demofg} {color}]\n");
-	(void) fprintf(stderr,
-		"\t[-{demobackground|demobg} {color}]\n");
+	(void) fprintf(stderr, optionsHelp);
 	exit(1);
 }
 
@@ -935,6 +907,8 @@ static XrmOptionDescRec options[] =
 	{(char *) "-other", (char *) "*abacus.format", XrmoptionNoArg, (char *) "other"},
 	{(char *) "-base", (char *) "*abacus.base", XrmoptionSepArg, NULL},
 	{(char *) "-displayBase", (char *) "*abacus.displayBase", XrmoptionSepArg, NULL},
+	{(char *) "-vertical", (char *) "*abacus.vertical", XrmoptionNoArg, (char *) "TRUE"},
+	{(char *) "-novertical", (char *) "*abacus.vertical", XrmoptionNoArg, (char *) "FALSE"},
 	{(char *) "-romanNumerals", (char *) "*abacus.romanNumerals", XrmoptionNoArg, (char *) "TRUE"},
 	{(char *) "-noromanNumerals", (char *) "*abacus.romanNumerals", XrmoptionNoArg, (char *) "FALSE"},
 	{(char *) "-sign", (char *) "*abacus.sign", XrmoptionNoArg, (char *) "TRUE"},
@@ -955,15 +929,11 @@ static XrmOptionDescRec options[] =
 	{(char *) "-notorient", (char *) "*abacus.topOrient", XrmoptionNoArg, (char *) "FALSE"},
 	{(char *) "-borient", (char *) "*abacus.bottomOrient", XrmoptionNoArg, (char *) "TRUE"},
 	{(char *) "-noborient", (char *) "*abacus.bottomOrient", XrmoptionNoArg, (char *) "FALSE"},
-#ifdef VERTICAL
-	{(char *) "-vertical", (char *) "*abacus.vertical", XrmoptionNoArg, (char *) "TRUE"},
-	{(char *) "-novertical", (char *) "*abacus.vertical", XrmoptionNoArg, (char *) "FALSE"},
-#endif
 	{(char *) "-delay", (char *) "*abacus.delay", XrmoptionSepArg, NULL},
 	{(char *) "-sound", (char *) "*abacus.sound", XrmoptionNoArg, (char *) "TRUE"},
 	{(char *) "-nosound", (char *) "*abacus.sound", XrmoptionNoArg, (char *) "FALSE"},
-	{(char *) "-bumpsound", (char *) "*abacus.bumpSound", XrmoptionSepArg, NULL},
-	{(char *) "-movesound", (char *) "*abacus.moveSound", XrmoptionSepArg, NULL},
+	{(char *) "-bumpSound", (char *) "*abacus.bumpSound", XrmoptionSepArg, NULL},
+	{(char *) "-moveSound", (char *) "*abacus.moveSound", XrmoptionSepArg, NULL},
 	{(char *) "-demo", (char *) "*abacus.demo", XrmoptionNoArg, (char *) "TRUE"},
 	{(char *) "-nodemo", (char *) "*abacus.demo", XrmoptionNoArg, (char *) "FALSE"},
 	{(char *) "-script", (char *) "*abacus.script", XrmoptionNoArg, (char *) "TRUE"},
@@ -974,7 +944,8 @@ static XrmOptionDescRec options[] =
 	{(char *) "-demoforeground", (char *) "*abacus.demoForeground", XrmoptionSepArg, NULL},
 	{(char *) "-demofg", (char *) "*abacus.demoForeground", XrmoptionSepArg, NULL},
 	{(char *) "-demobackground", (char *) "*abacus.demoBackground", XrmoptionSepArg, NULL},
-	{(char *) "-demobg", (char *) "*abacus.demoBackground", XrmoptionSepArg, NULL}
+	{(char *) "-demobg", (char *) "*abacus.demoBackground", XrmoptionSepArg, NULL},
+	{(char *) "-version", (char *) "*abacus.versionOnly", XrmoptionNoArg, (char *) "TRUE"}
 };
 
 static void
@@ -985,14 +956,13 @@ PrintState(Widget w, char *msg
 )
 {
 #ifdef HAVE_MOTIF
-	XtSetArg(arg[0], XmNvalue, msg);
+	XtVaSetValues(w, XmNvalue, msg, NULL);
 #else
 	(void) sprintf(titleDsp, "%s %s =%s",
 		(mode < 0 || mode > MAXMODES) ? "" : formatString[mode],
 		progDsp, msg);
-	XtSetArg(arg[0], XtNtitle, titleDsp);
+	XtVaSetValues(w, XtNtitle, titleDsp, NULL);
 #endif
-	XtSetValues(w, arg, 1);
 }
 
 /* There's probably a better way to assure that they are the same but I do
@@ -1060,21 +1030,20 @@ CallbackAbacusDemo(Widget w, caddr_t clientData, abacusCallbackStruct * callData
 			if (callData->aux == PRIMARY)
 #endif
 			{
-				XtSetArg(arg[0], XtNdeck, callData->deck);
-				XtSetArg(arg[1], XtNrail, callData->rail);
-				XtSetArg(arg[2], XtNnumber, callData->number);
-				XtSetValues(AUXWIN(callData->aux), arg, 3);
+				XtVaSetValues(AUXWIN(callData->aux),
+					XtNdeck, callData->deck,
+					XtNrail, callData->rail,
+					XtNnumber, callData->number, NULL);
 			}
 			break;
 		case ABACUS_CLEAR:
-			XtSetArg(arg[0], XtNdeck, ABACUS_CLEAR);
-			XtSetValues(abacus, arg, 1);
+			XtVaSetValues(abacus, XtNdeck, ABACUS_CLEAR, NULL);
 #ifdef LEE_ABACUS
 			/* Abacus demo clear is more complete */
-			XtSetArg(arg[0], XtNdeck, ABACUS_CLEAR);
-			XtSetValues(leftAuxAbacus, arg, 1);
-			XtSetArg(arg[0], XtNdeck, ABACUS_CLEAR);
-			XtSetValues(rightAuxAbacus, arg, 1);
+			XtVaSetValues(leftAuxAbacus,
+				XtNdeck, ABACUS_CLEAR, NULL);
+			XtVaSetValues(rightAuxAbacus,
+				XtNdeck, ABACUS_CLEAR, NULL);
 #endif
 			break;
 		case ABACUS_DEMO:
@@ -1082,13 +1051,13 @@ CallbackAbacusDemo(Widget w, caddr_t clientData, abacusCallbackStruct * callData
 #ifndef HAVE_MOTIF
 			XtDestroyWidget(shell);
 #endif
-			XtSetArg(arg[0], XtNdemo, False);
-			XtSetValues(abacus, arg, 1);
+			XtVaSetValues(abacus,
+				XtNdemo, False, NULL);
 #ifdef LEE_ABACUS
-			XtSetArg(arg[0], XtNdemo, False);
-			XtSetValues(leftAuxAbacus, arg, 1);
-			XtSetArg(arg[0], XtNdemo, False);
-			XtSetValues(rightAuxAbacus, arg, 1);
+			XtVaSetValues(leftAuxAbacus,
+				XtNdemo, False, NULL);
+			XtVaSetValues(rightAuxAbacus,
+				XtNdemo, False, NULL);
 #endif
 			break;
 	}
@@ -1109,7 +1078,7 @@ CallbackAbacusDemo(Widget w, caddr_t clientData, abacusCallbackStruct * callData
 }
 
 static void
-forceNormalParams()
+forceNormalParams(Widget w)
 {
 	int base = DEFAULTBASE;
 	int displayBase = DEFAULTBASE;
@@ -1120,18 +1089,18 @@ forceNormalParams()
 		XmScaleSetValue(abacusBaseSlider, base);
 	}
 #endif
-	XtSetArg(arg[0], XtNbase, base);
-	XtSetArg(arg[1], XtNdisplayBase, displayBase);
-	XtSetValues(abacus, arg, 2);
+	XtVaSetValues(abacus,
+		XtNbase, base,
+		XtNdisplayBase, displayBase, NULL);
 }
 
 static void
-forceDemoParams()
+forceDemoParams(Widget w)
 {
 	int rails, min, mode;
 	Boolean demo, sign, quarter, quarterPercent;
 
-	forceNormalParams();
+	forceNormalParams(w);
 	XtVaGetValues(abacus,
 		XtNmode, &mode,
 		XtNrails, &rails,
@@ -1141,11 +1110,11 @@ forceDemoParams()
 		XtNdemo, &demo, NULL);
 	if (mode == OTHER) {
 		mode = CHINESE;
-		XtSetArg(arg[0], XtNmode, mode);
-		XtSetValues(abacus, arg, 1);
+		XtVaSetValues(abacus,
+			XtNmode, mode, NULL);
 #ifdef HAVE_MOTIF
-		XtSetArg(arg[0], XmNmenuHistory, formatOptions[mode]);
-		XtSetValues(formatMenu, arg, 1);
+		XtVaSetValues(formatMenu,
+			XmNmenuHistory, formatOptions[mode], NULL);
 #endif
 	}
 	min = ((sign) ? 1: 0) + ((quarter) ? 1 : 0) +
@@ -1155,8 +1124,19 @@ forceDemoParams()
 #ifdef HAVE_MOTIF
 		XmScaleSetValue(sizeSlider, min);
 #endif
-		XtSetArg(arg[0], XtNrails, min);
-		XtSetValues(abacus, arg, 1);
+		XtVaSetValues(abacus, XtNrails, min, NULL);
+	}
+}
+
+static void
+Initialize(Widget w)
+{
+	Boolean versionOnly;
+
+	XtVaGetValues(w, XtNversionOnly, &versionOnly, NULL);
+	if (versionOnly) {
+		(void) printf(aboutHelp);
+		exit(0);
 	}
 }
 
@@ -1172,10 +1152,10 @@ createDemo(void)
 #else
 	shell = XtCreateApplicationShell(titleDsp,
 		topLevelShellWidgetClass, NULL, 0);
-	XtSetArg(arg[0], XtNiconPixmap, abacusIcon);
-	XtSetArg(arg[1], XtNinput, True);
-	XtSetArg(arg[2], XtNtitle, titleDspDemo);
-	XtSetValues(shell, arg, 3);
+	XtVaSetValues(shell,
+		XtNiconPixmap, abacusIcon,
+		XtNinput, True,
+		XtNtitle, titleDspDemo, NULL);
 	abacusDemo = XtCreateManagedWidget("abacus",
 		abacusDemoWidgetClass, shell, NULL, 0);
 	XtAddCallback(abacusDemo, XtNselectCallback,
@@ -1218,8 +1198,7 @@ CallbackAbacus(Widget w, caddr_t clientData, abacusCallbackStruct * callData)
 #ifdef HAVE_MOTIF
 			XtManageChild(clearDialog);
 #else
-			XtSetArg(arg[0], XtNmenu, 1); /* menu choice */
-			XtSetValues(w, arg, 1);
+			XtVaSetValues(w, XtNmenu, 1, NULL); /* menu choice */
 #endif
 			break;
 		case ABACUS_SCRIPT:
@@ -1234,20 +1213,19 @@ CallbackAbacus(Widget w, caddr_t clientData, abacusCallbackStruct * callData)
 			if (callData->aux == PRIMARY)
 #endif
 			{
-				XtSetArg(arg[0], XtNdeck, callData->deck);
-				XtSetArg(arg[1], XtNrail, callData->rail);
-				XtSetArg(arg[2], XtNnumber, callData->number);
-				XtSetValues(AUXWIN(callData->aux), arg, 3);
+				XtVaSetValues(AUXWIN(callData->aux),
+					XtNdeck, callData->deck,
+					XtNrail, callData->rail,
+					XtNnumber, callData->number, NULL);
 			}
 			break;
 		case ABACUS_CLEAR:
-			XtSetArg(arg[0], XtNdeck, ABACUS_CLEAR);
-			XtSetValues(abacusDemo, arg, 1);
+			XtVaSetValues(abacusDemo, XtNdeck, ABACUS_CLEAR, NULL);
 			break;
 		case ABACUS_DEMO:
 			demo = !demo;
 			if (demo) {
-				forceDemoParams();
+				forceDemoParams(abacus);
 				createDemo();
 			} else {
 				XtDestroyWidget(abacusDemo);
@@ -1255,26 +1233,21 @@ CallbackAbacus(Widget w, caddr_t clientData, abacusCallbackStruct * callData)
 				XtDestroyWidget(shell);
 #endif
 			}
-			XtSetArg(arg[0], XtNdemo, demo);
-			XtSetValues(abacus, arg, 1);
+			XtVaSetValues(abacus, XtNdemo, demo, NULL);
 #ifdef LEE_ABACUS
-			XtSetArg(arg[0], XtNdemo, demo);
-			XtSetValues(leftAuxAbacus, arg, 1);
-			XtSetArg(arg[0], XtNdemo, demo);
-			XtSetValues(rightAuxAbacus, arg, 1);
+			XtVaSetValues(leftAuxAbacus, XtNdemo, demo, NULL);
+			XtVaSetValues(rightAuxAbacus, XtNdemo, demo, NULL);
 #endif
 			break;
 		case ABACUS_NEXT:
-			XtSetArg(arg[0], XtNdeck, ABACUS_NEXT);
-			XtSetValues(abacusDemo, arg, 1);
+			XtVaSetValues(abacusDemo, XtNdeck, ABACUS_NEXT, NULL);
 			break;
 		case ABACUS_REPEAT:
-			XtSetArg(arg[0], XtNdeck, ABACUS_REPEAT);
-			XtSetValues(abacusDemo, arg, 1);
+			XtVaSetValues(abacusDemo,
+				XtNdeck, ABACUS_REPEAT, NULL);
 			break;
 		case ABACUS_MORE:
-			XtSetArg(arg[0], XtNdeck, ABACUS_MORE);
-			XtSetValues(abacusDemo, arg, 1);
+			XtVaSetValues(abacusDemo, XtNdeck, ABACUS_MORE, NULL);
 			break;
 		case ABACUS_INC:
 			if (w == abacus) {
@@ -1283,8 +1256,7 @@ CallbackAbacus(Widget w, caddr_t clientData, abacusCallbackStruct * callData)
 #ifdef HAVE_MOTIF
 				if (rails > MAXRAILS)
 					XtVaSetValues(sizeSlider,
-						XmNmaximum, rails,
-						NULL);
+						XmNmaximum, rails, NULL);
 				XmScaleSetValue(sizeSlider, rails);
 #endif
 			}
@@ -1297,8 +1269,7 @@ CallbackAbacus(Widget w, caddr_t clientData, abacusCallbackStruct * callData)
 				XmScaleSetValue(sizeSlider, rails);
 				if (rails >= MAXRAILS)
 					XtVaSetValues(sizeSlider,
-						XmNmaximum, rails,
-						NULL);
+						XmNmaximum, rails, NULL);
 #endif
 			}
 			break;
@@ -1306,16 +1277,28 @@ CallbackAbacus(Widget w, caddr_t clientData, abacusCallbackStruct * callData)
 			if (w == abacus) {
 #ifdef HAVE_MOTIF
 				XtVaSetValues(formatMenu,
-					 XmNmenuHistory, formatOptions[mode],
-					 NULL);
+					XmNmenuHistory, formatOptions[mode],
+					NULL);
 #endif
 				if (demo) {
-					XtSetArg(arg[0], XtNdeck, ABACUS_CLEAR);
-					XtSetArg(arg[1], XtNmode, mode);
-					XtSetValues(abacusDemo, arg, 2);
+					XtVaSetValues(abacusDemo,
+						XtNdeck, ABACUS_CLEAR,
+						XtNmode, mode, NULL);
 				}
 			}
 			break;
+		case ABACUS_VERTICAL:
+			XtVaGetValues(w,
+				XtNvertical, &vertical, NULL);
+#ifdef HAVE_MOTIF
+#ifdef TOGGLES
+			if (w == abacus) {
+				XmToggleButtonSetState(verticalSwitch,
+					vertical, False);
+			}
+#endif
+#endif
+			break;
 		case ABACUS_ROMANNUMERAL:
 			XtVaGetValues(w,
 				XtNromanNumerals, &romanNumerals,
@@ -1344,7 +1327,8 @@ CallbackAbacus(Widget w, caddr_t clientData, abacusCallbackStruct * callData)
 #ifdef HAVE_MOTIF
 #ifdef TOGGLES
 			if (w == abacus) {
-				XmToggleButtonSetState(quarterSwitch, quarter, False);
+				XmToggleButtonSetState(quarterSwitch,
+					quarter, False);
 			}
 #endif
 #endif
@@ -1355,18 +1339,8 @@ CallbackAbacus(Widget w, caddr_t clientData, abacusCallbackStruct * callData)
 #ifdef HAVE_MOTIF
 #ifdef TOGGLES
 			if (w == abacus) {
-				XmToggleButtonSetState(quarterPercentSwitch, quarterPercent, False);
-			}
-#endif
-#endif
-			break;
-		case ABACUS_VERTICAL:
-			XtVaGetValues(w,
-				XtNvertical, &vertical, NULL);
-#ifdef HAVE_MOTIF
-#ifdef TOGGLES
-			if (w == abacus) {
-				XmToggleButtonSetState(verticalSwitch, vertical, False);
+				XmToggleButtonSetState(quarterPercentSwitch,
+					quarterPercent, False);
 			}
 #endif
 #endif
@@ -1414,9 +1388,9 @@ CallbackAbacusMath(Widget w, caddr_t clientData, abacusCallbackStruct * callData
 			}
 		}
 		/* check for math ops */
-		XtSetArg(arg[0], XtNdeck, ABACUS_CALC);
-		XtSetArg(arg[1], XtNmathBuffer, mathBuffer);
-		XtSetValues(abacus, arg, 2);
+		XtVaSetValues(abacus,
+			XtNdeck, ABACUS_CALC,
+			XtNmathBuffer, mathBuffer, NULL);
 	}
 }
 
@@ -1424,8 +1398,7 @@ static void
 CallbackAbacusClear(Widget w, XtPointer clientData, XmAnyCallbackStruct * cbs)
 {
 	if (cbs->reason == XmCR_OK) {
-		XtSetArg(arg[0], XtNmenu, 1); /* menu choice */
-		XtSetValues(abacus, arg, 1);
+		XtVaSetValues(abacus, XtNmenu, 1, NULL); /* menu choice */
 	}
 }
 
@@ -1501,7 +1474,6 @@ DisplayBaseSlider(Widget w, XtPointer clientData, XmScaleCallbackStruct * cbs)
 }
 
 #ifdef TOGGLES
-#ifdef VERTICAL
 static void
 VerticalToggle(Widget w, XtPointer clientData, XmToggleButtonCallbackStruct * cbs)
 {
@@ -1510,7 +1482,6 @@ VerticalToggle(Widget w, XtPointer clientData, XmToggleButtonCallbackStruct * cb
 	XtVaSetValues(abacus,
 		XtNvertical, vertical, NULL);
 }
-#endif
 
 static void
 RomanNumeralToggle(Widget w, XtPointer clientData,
@@ -1646,18 +1617,16 @@ complexityCB(Widget w, void *value, void *clientData)
 	}
 	if (val == DEMO) {
 		if (baseSet) {
-			forceNormalParams();
+			forceNormalParams(abacus);
 			baseSet = False;
 			destroyBase();
 		}
-		forceDemoParams();
-		XtSetArg(arg[0], XtNdemo, !wasDemo);
-		XtSetValues(abacus, arg, 1);
+		forceDemoParams(abacus);
+		XtVaSetValues(abacus, XtNdemo, !wasDemo, NULL);
 		createDemo();
 	} else {
 		if (wasDemo) {
-			XtSetArg(arg[0], XtNdemo, !wasDemo);
-			XtSetValues(abacus, arg, 1);
+			XtVaSetValues(abacus, XtNdemo, !wasDemo, NULL);
 			XtDestroyWidget(abacusDemo);
 		}
 		if (val == BASE) {
@@ -1666,7 +1635,7 @@ complexityCB(Widget w, void *value, void *clientData)
 			baseSet = True;
 			createBase(DEFAULTBASE, DEFAULTBASE);
 		} else if (baseSet) {
-			forceNormalParams();
+			forceNormalParams(abacus);
 			baseSet = False;
 			destroyBase();
 		}
@@ -1685,17 +1654,15 @@ formatCB(Widget w, void *value, void *clientData)
 	if (mode < 0 && mode > MAXFORMATS)
 		mode = OTHER;
 	if (demo && mode == OTHER) {
-			XtSetArg(arg[0], XmNmenuHistory,
-				formatOptions[oldMode]);
-			XtSetValues(formatMenu, arg, 1);
+			XtVaSetValues(formatMenu,
+				XmNmenuHistory, formatOptions[oldMode], NULL);
 			return;
 	}
-	XtSetArg(arg[0], XtNmode, mode);
-	XtSetValues(abacus, arg, 1);
+	XtVaSetValues(abacus, XtNmode, mode, NULL);
 	if (demo) {
-		XtSetArg(arg[0], XtNdeck, ABACUS_CLEAR);
-		XtSetArg(arg[1], XtNmode, mode);
-		XtSetValues(abacusDemo, arg, 2);
+		XtVaSetValues(abacusDemo,
+			XtNdeck, ABACUS_CLEAR,
+			XtNmode, mode, NULL);
 	}
 }
 
@@ -1706,16 +1673,14 @@ fileCB(Widget w, void *value, void *clientData)
 
 	if (val == 0)
 		exit(0);
-	XtSetArg(arg[0], XtNmenu, val);
-	XtSetValues(abacus, arg, 1);
+	XtVaSetValues(abacus, XtNmenu, val, NULL);
 }
 
 static void
 controlsCB(Widget w, void *value, void *clientData)
 {
 	int val = (int) value;
-	XtSetArg(arg[0], XtNmenu, val + 1); /* Q */
-	XtSetValues(abacus, arg, 1);
+	XtVaSetValues(abacus, XtNmenu, val + 1, NULL); /* Q */
 }
 
 static Widget
@@ -1786,22 +1751,25 @@ helpCB(Widget w, XtPointer value, XtPointer clientData)
 		XtManageChild(featuresDialog);
 		break;
 	case 2:
-		XtManageChild(options1Dialog);
+		XtManageChild(optionsDialog);
 		break;
 	case 3:
-		XtManageChild(options2Dialog);
+		XtManageChild(options1Dialog);
 		break;
 	case 4:
-		XtManageChild(referencesDialog);
+		XtManageChild(options2Dialog);
 		break;
 	case 5:
+		XtManageChild(referencesDialog);
+		break;
+	case 6:
 		XtManageChild(aboutDialog);
 		break;
 	default:
 		{
 			char *buf;
 
-			intCat(&buf, "helpCB: %d\n", val);
+			intCat(&buf, "helpCB: %d", val);
 			XtWarning(buf);
 			free(buf);
 		}
@@ -1828,16 +1796,14 @@ main(int argc, char **argv)
 #endif
 	XmString fileString, controlsString;
 	XmString quitString, clearString, incrementString, decrementString;
+	XmString verticalString;
 	XmString romanNumeralString, signString, quarterString;
-	XmString speedString, slowString, soundString;
-	XmString complexity, complexityStrings[COMPLEXITIES];
-	XmString format, formatStrings[MAXMODES];
 #ifdef QUARTER_PERCENT
 	XmString quarterPercentString;
 #endif
-#ifdef VERTICAL
-	XmString verticalString;
-#endif
+	XmString speedString, slowString, soundString;
+	XmString complexity, complexityStrings[COMPLEXITIES];
+	XmString format, formatStrings[MAXMODES];
 	int rails, mode;
 	Boolean romanNumerals, sign, quarter, quarterPercent;
 	unsigned int i;
@@ -1876,11 +1842,10 @@ main(int argc, char **argv)
 			RootWindowOfScreen(XtScreen(topLevel)),
 			(char *) abacus_bits,
 			abacus_width, abacus_height);
-	XtSetArg(arg[0], XtNiconPixmap, abacusIcon);
 #ifdef HAVE_MOTIF
-	/* not XmEXPLICIT */
-	XtSetArg(arg[1], XmNkeyboardFocusPolicy, XmPOINTER);
-	XtSetValues(topLevel, arg, 2);
+	XtVaSetValues(topLevel,
+		XtNiconPixmap, abacusIcon,
+		XmNkeyboardFocusPolicy, XmPOINTER, NULL); /* not XmEXPLICIT */
 	menuBarPanel = XtVaCreateManagedWidget("menuBarPanel",
 		xmPanedWindowWidgetClass, topLevel,
 		XmNseparatorOn, False,
@@ -1904,14 +1869,12 @@ main(int argc, char **argv)
 	incrementString = XmStringCreateSimple((char *) "Increment");
 	decrementString = XmStringCreateSimple((char *) "Decrement");
 	format = XmStringCreateSimple((char *) "Format");
+	verticalString = XmStringCreateSimple((char *) "Vertical");
 	romanNumeralString = XmStringCreateSimple((char *) "RoMan Numerals");
 	signString = XmStringCreateSimple((char *) "Sign");
 	quarterString = XmStringCreateSimple((char *) "QUarter");
 #ifdef QUARTER_PERCENT
 	quarterPercentString = XmStringCreateSimple((char *) "Quarter Percent");
-#endif
-#ifdef VERTICAL
-	verticalString = XmStringCreateSimple((char *) "Vertical");
 #endif
 	speedString = XmStringCreateSimple((char *) ">Speed");
 	slowString = XmStringCreateSimple((char *) "<Slow");
@@ -1921,6 +1884,7 @@ main(int argc, char **argv)
 		XmVaPUSHBUTTON, incrementString, 'I', NULL, NULL,
 		XmVaPUSHBUTTON, decrementString, 'D', NULL, NULL,
 		XmVaPUSHBUTTON, format, 'F', NULL, NULL,
+		XmVaPUSHBUTTON, verticalString, 'V', NULL, NULL,
 		XmVaPUSHBUTTON, romanNumeralString, 'M', NULL, NULL,
 		XmVaPUSHBUTTON, signString, 'S', NULL, NULL,
 		XmVaPUSHBUTTON, quarterString, 'U', NULL, NULL,
@@ -1930,23 +1894,18 @@ main(int argc, char **argv)
 		/* Reorder the following when working */
 #ifdef QUARTER_PERCENT
 		XmVaPUSHBUTTON, quarterPercentString, 'P', NULL, NULL,
-#endif
-#ifdef VERTICAL
-		XmVaPUSHBUTTON, verticalString, 'V', NULL, NULL,
 #endif
 		NULL);
 	XmStringFree(clearString);
 	XmStringFree(incrementString);
 	XmStringFree(decrementString);
 	XmStringFree(format);
+	XmStringFree(verticalString);
 	XmStringFree(romanNumeralString);
 	XmStringFree(signString);
 	XmStringFree(quarterString);
 #ifdef QUARTER_PERCENT
 	XmStringFree(quarterPercentString);
-#endif
-#ifdef VERTICAL
-	XmStringFree(verticalString);
 #endif
 	XmStringFree(speedString);
 	XmStringFree(slowString);
@@ -1987,6 +1946,8 @@ main(int argc, char **argv)
 		(char *) "Description");
 	featuresDialog = createHelp(menuBar, (char *) featuresHelp,
 		(char *) "Features");
+	optionsDialog = createHelp(menuBar, (char *) optionsHelp,
+		(char *) "Options");
 	options1Dialog = createHelp(menuBar, (char *) options1Help,
 		(char *) "Options1");
 	options2Dialog = createHelp(menuBar, (char *) options2Help,
@@ -2165,8 +2126,9 @@ main(int argc, char **argv)
 		NULL);
 #endif
 #else
-	XtSetArg(arg[1], XtNinput, True);
-	XtSetValues(topLevel, arg, 2);
+	XtVaSetValues(topLevel,
+		XtNiconPixmap, abacusIcon,
+		XtNinput, True, NULL);
 	abacus = XtCreateManagedWidget("abacus",
 		abacusWidgetClass, topLevel, NULL, 0);
 #endif
@@ -2188,12 +2150,10 @@ main(int argc, char **argv)
 #ifdef HAVE_MOTIF
 #ifdef TOGGLES
 	{
-#ifdef VERTICAL
 	verticalSwitch= XtVaCreateManagedWidget("Vertical",
 		xmToggleButtonGadgetClass, toggleRowCol, NULL);
 	XtAddCallback(verticalSwitch, XmNvalueChangedCallback,
 		(XtCallbackProc) VerticalToggle, (XtPointer) NULL);
-#endif
 	romanNumeralSwitch= XtVaCreateManagedWidget("Roman",
 		xmToggleButtonGadgetClass, toggleRowCol, NULL);
 	XtAddCallback(romanNumeralSwitch, XmNvalueChangedCallback,
@@ -2288,11 +2248,12 @@ main(int argc, char **argv)
 	if (baseSet) {
 		createBase(base, displayBase);
 	} else {
-		forceNormalParams();
+		forceNormalParams(abacus);
 	}
 #endif
+	Initialize(abacus);
 	if (demo)
-		forceDemoParams();
+		forceDemoParams(abacus);
 	XtRealizeWidget(topLevel);
 	XGrabButton(XtDisplay(abacus), (unsigned int) AnyButton, AnyModifier,
 		XtWindow(abacus), TRUE, (unsigned int) (ButtonPressMask |
